import React from 'react'
import { render, screen, waitFor } from 'test-utils'
import AdapterDateFns from '@mui/lab/AdapterDateFns'
import { LocalizationProvider } from '@mui/lab'
import GuestRegisterStep from './register'
import { GuestRegisterData } from '../enteredGuestData'
import AuthenticationMethod from '../authenticationMethod'
import { GuestInviteInformation } from '../guestDataForm'

function getEmptyGuestData(): GuestInviteInformation {
  return {
    first_name: '',
    last_name: '',
    ou_name_en: '',
    ou_name_nb: '',
    role_name_en: '',
    role_name_nb: '',
    role_start: '',
    role_end: '',
    comment: '',
    email: '',
    mobile_phone: '',
    date_of_birth: null,
    fnr: '',
    passport: '',
    countryForCallingCode: '',
    authentication_method: AuthenticationMethod.Invite,
  }
}

test('Guest register page showing passport field on manual registration', async () => {
  const nextHandler = (registerData: GuestRegisterData) => {
    console.log(`Entered data: ${registerData}`)
  }

  render(
    <LocalizationProvider dateAdapter={AdapterDateFns}>
      <GuestRegisterStep
        nextHandler={nextHandler}
        initialGuestData={getEmptyGuestData()}
        registerData={null}
      />
    </LocalizationProvider>
  )

  await waitFor(() => {
    expect(screen.queryByTestId('passport_number_input')).toBeInTheDocument()
  })
})

test('Name not editable if present and invite is Feide', async () => {
  const nextHandler = (registerData: GuestRegisterData) => {
    console.log(`Entered data: ${registerData}`)
  }

  const testData = getEmptyGuestData()
  testData.authentication_method = AuthenticationMethod.Feide
  testData.first_name = 'Test'
  testData.last_name = 'Tester'

  render(
    <LocalizationProvider dateAdapter={AdapterDateFns}>
      <GuestRegisterStep
        nextHandler={nextHandler}
        initialGuestData={testData}
        registerData={null}
      />
    </LocalizationProvider>
  )

  await waitFor(() => {
    expect(screen.queryByTestId('first-name-input-text')).toBeDisabled()
    expect(screen.queryByTestId('last-name-input-text')).toBeDisabled()
  })
})

test('Name editable if missing and invite is Feide', async () => {
  const nextHandler = (registerData: GuestRegisterData) => {
    console.log(`Entered data: ${registerData}`)
  }

  const testData = getEmptyGuestData()
  testData.authentication_method = AuthenticationMethod.Feide

  render(
    <LocalizationProvider dateAdapter={AdapterDateFns}>
      <GuestRegisterStep
        nextHandler={nextHandler}
        initialGuestData={testData}
        registerData={null}
      />
    </LocalizationProvider>
  )

  await waitFor(() => {
    expect(screen.queryByTestId('first-name-input-text')).toBeEnabled()
    expect(screen.queryByTestId('last-name-input-text')).toBeEnabled()
  })
})

test('Identifier fields disabled if invite if Feide and national ID present', async () => {
  const nextHandler = (registerData: GuestRegisterData) => {
    console.log(`Entered data: ${registerData}`)
  }

  const testData = getEmptyGuestData()
  testData.authentication_method = AuthenticationMethod.Feide
  testData.fnr = '12042335418'

  render(
    <LocalizationProvider dateAdapter={AdapterDateFns}>
      <GuestRegisterStep
        nextHandler={nextHandler}
        initialGuestData={testData}
        registerData={null}
      />
    </LocalizationProvider>
  )

  await waitFor(() => {
    expect(screen.queryByTestId('national-id-number-input')).toBeDisabled()
    expect(screen.queryByTestId('passport_number_input')).toBeDisabled()
    expect(screen.queryByTestId('passport-nationality-input')).toBeDisabled()
  })
})

test('Identifier fields enabled if invite if Feide but national ID number missing', async () => {
  const nextHandler = (registerData: GuestRegisterData) => {
    console.log(`Entered data: ${registerData}`)
  }

  const testData = getEmptyGuestData()
  testData.authentication_method = AuthenticationMethod.Feide
  testData.fnr = ''

  render(
    <LocalizationProvider dateAdapter={AdapterDateFns}>
      <GuestRegisterStep
        nextHandler={nextHandler}
        initialGuestData={testData}
        registerData={null}
      />
    </LocalizationProvider>
  )

  await waitFor(() => {
    expect(screen.queryByTestId('national-id-number-input')).toBeEnabled()
    expect(screen.queryByTestId('passport_number_input')).toBeEnabled()
    expect(screen.queryByTestId('passport-nationality-input')).toBeEnabled()
  })
})
